* Generates Figure 9 in Desmet, Nagy and Rossi-Hansberg (JPE) and related results discussed after equation (41)
* September 2016

clear all
set memory 1G
set matsize 2000
use CBSA_Data.dta, replace

***************************************************************
* BASIC REGRESSION
***************************************************************

* basic regression: payroll per worker at zip code on employment density at zip code, interaction of employment density at zip code and payroll per worker at cbsa, and cbsa fixed effects
* theory predicts negative effect of lempdens and positive effect of interaction term
reg lannpaypw2000 lempdens2000 lempdenscbsaannpaypw2000
reg lannpaypw2010 lempdens2010 lempdenscbsaannpaypw2010

***************************************************************
* SEPARATE REGRESSION FOR EACH CBSA
***************************************************************

drop if lempdens2010==.
sort cbsa
egen indcbsa = group(cbsa)
sort indcbsa
by indcbsa: gen numberobs=_N 
drop if numberobs < 6
sort cbsa
drop indcbsa
egen indcbsa=group(cbsa)
sum indcbsa
scalar maxindcbsa=r(max)
local maxindcbsa2=maxindcbsa

matrix outcome2010=J(`maxindcbsa2',2,.)

forvalues x=1(1)`maxindcbsa2'{
			preserve
			quiet keep if indcbsa==`x'
			quiet sum lcbsaannpaypw2010
			quiet scalar outannpaypw2010=r(mean)
			quiet reg lannpaypw2010 lempdens2010  
			quiet scalar coeffempdens2010=_b[lempdens2010]
			matrix outcome2010[`x',1]=outannpaypw2010
			matrix outcome2010[`x',2]=coeffempdens2010
       	    restore
}


mat list outcome2010
svmat outcome2010, names(results2010)
keep results2010* 

rename results20101 lcbsaannpaypw2010
rename results20102 coefflempdens2010

sort lcbsaannpaypw2010
reg coefflempdens2010 lcbsaannpaypw2010
predict predcoefflempdens2010, xb
sort lcbsaannpaypw2010
twoway (scatter coefflempdens2010 lcbsaannpaypw2010, mcolor(black)) (line predcoefflempdens2010 lcbsaannpaypw2010, lcolor(black)), xtitle(Log Payroll per Worker CBSA 2010) ytitle(Effect Log Worker Density on Log Payroll per Worker (ZIP)) graphregion(fcolor(white)) legend(off) saving(fig9,replace)



