* Generates Table 5 in Desmet, Nagy and Rossi-Hansberg (JPE) 
* September 2016

clear
set memory 1g
use celldensity_data.dta

* prepare data
gen productivity=w/p
gen lproductivity=log(w/p)
gen lpop=log(l)
gen counter=1
drop if c==0
drop if w==0

* 1. Correlation productivity and density across all cells of the world
corr lproductivity lpop

* 2. Weighted average of within-country correlation of productivity and density (weights=number of cells)
sort isocode
bys isocode: egen corrcountry=corr(lproductivity lpop)
egen avcorrcountry=mean(corrcountry)
sum avcorrcountry

* 3. Correlation for rich and poor cells
sum w if w > 0, detail 
scalar mediancell=r(p50)
corr lproductivity lpop if w > mediancell
corr lproductivity lpop if w <= mediancell

* 4. Correlation for rich and poor cells within countries
sort isocode
bys isocode: egen perc50=pctile(w), p(50)
sort isocode w
bys isocode: egen corrmedup=corr(lproductivity lpop) if w>perc50
bys isocode: egen corrmeddown=corr(lproductivity lpop) if w<=perc50
bys isocode: egen cellscountry=total(counter)
sum corrmedup if cellscountry > 50
sum corrmeddown if cellscountry > 50

* 5. Correlation by continent
sort continent
corr lproductivity lpop if continent=="Africa"
corr lproductivity lpop if continent=="Europe"
corr lproductivity lpop if continent=="Asia"
corr lproductivity lpop if wb_nam==1
corr lproductivity lpop if wb_lac==1
corr lproductivity lpop if ausnzl==1
corr lproductivity lpop if westeurope==1

