* Generates Table 4 in Desmet, Nagy and Rossi-Hansberg (JPE) and related results discussed after equation (41)
* September 2016

clear all
set memory 1G
use zipall.dta

label variable zcta "ZIP Code Tabulation Area (ZCTA)"
label variable incomepc2011 "Per capita income, 5-year average, 2007-2011 (American Community Service)"
label variable incomepc2000 "Per capita income 2000 (Census 2000)"
label variable earnings2011 "Mean earnings for full-time year-round workers, 5-year average, 2007-2011 (American Community Service)"
label variable earnings2000 "Mean earnings for full-time year-round workers 2000 (Census 2000)"
label variable pop2011 "Population, 5-year average, 2007-2011 (American Community Service)"
label variable pop2000 "Population 2000 (Census 2000)"
label variable landarea "Land area in sq m (Census)"
drop waterarea
save zip_data.dta, replace

/*

* DROP PUERTO RICO, HAWAII AND ALASKA
drop if zcta < 1001
drop if zcta > 96700 & zcta < 96864
drop if zcta > 99500 & zcta < 99930

/*

* PREPARE DATASET

gen learnings2000=log(earnings2000)
gen learnings2011=log(earnings2011)
gen popdens2000=pop2000/(landarea*0.000001)
gen popdens2011=pop2011/(landarea*0.000001)
gen lpopdens2000=log(pop2000/(landarea*0.000001))
gen lpopdens2011=log(pop2011/(landarea*0.000001))
gen lincomepc2000=log(incomepc2000)
gen lincomepc2011=log(incomepc2011)

* CORRELATIONS EARNINGS (Table 4, Panel A)

foreach x in 2000 2011{
	sum learnings`x', detail
	scalar learnings`x'p25=r(p25)
	scalar learnings`x'p50=r(p50)
	scalar learnings`x'p75=r(p75)
	pwcorr learnings`x' lpopdens`x' if learnings`x' < learnings`x'p25, obs sig
	pwcorr learnings`x' lpopdens`x' if (learnings`x' >= learnings`x'p25 & learnings`x' < learnings`x'p50), obs sig
	pwcorr learnings`x' lpopdens`x' if (learnings`x' >= learnings`x'p50 & learnings`x' < learnings`x'p75), obs sig
	pwcorr learnings`x' lpopdens`x' if learnings`x' >= learnings`x'p75, obs sig
	pwcorr learnings`x' lpopdens`x' if learnings`x' < learnings`x'p50, obs sig
	pwcorr learnings`x' lpopdens`x' if learnings`x' >= learnings`x'p50, obs sig
	}

* CORRELATIONS INCOME (Table 4, Panel B)

foreach x in 2000 2011{
	sum lincomepc`x', detail
	scalar lincomepc`x'p25=r(p25)
	scalar lincomepc`x'p50=r(p50)
	scalar lincomepc`x'p75=r(p75)
	pwcorr lincomepc`x' lpopdens`x' if lincomepc`x' < lincomepc`x'p25, obs sig
	pwcorr lincomepc`x' lpopdens`x' if (lincomepc`x' >= lincomepc`x'p25 & lincomepc`x' < lincomepc`x'p50), obs sig
	pwcorr lincomepc`x' lpopdens`x' if (lincomepc`x' >= lincomepc`x'p50 & lincomepc`x' < lincomepc`x'p75), obs sig
	pwcorr lincomepc`x' lpopdens`x' if lincomepc`x' >= lincomepc`x'p75, obs sig
	pwcorr lincomepc`x' lpopdens`x' if lincomepc`x' < lincomepc`x'p50, obs sig
	pwcorr lincomepc`x' lpopdens`x' if lincomepc`x' >= lincomepc`x'p50, obs sig
	}

